about summary refs log tree commit diff
path: root/src/libstd/sys
diff options
context:
space:
mode:
authorBaoshan Pang <baoshan.pang@windriver.com>2019-09-25 20:10:29 -0700
committerBaoshan Pang <baoshan.pang@windriver.com>2019-09-25 20:10:29 -0700
commitdd38a0f6c72928b59ffc266f52954b6cfcc5f491 (patch)
tree2f75388db8d67905ec5ebc103532ff31ab7f4da0 /src/libstd/sys
parent75ecbe2d841f818e217e3669520fc6d6ec6b0a3b (diff)
downloadrust-dd38a0f6c72928b59ffc266f52954b6cfcc5f491.tar.gz
rust-dd38a0f6c72928b59ffc266f52954b6cfcc5f491.zip
update rtpSpawn's parameters type(It's prototype has been updated in libc)
Diffstat (limited to 'src/libstd/sys')
-rw-r--r--src/libstd/sys/vxworks/process/process_vxworks.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libstd/sys/vxworks/process/process_vxworks.rs b/src/libstd/sys/vxworks/process/process_vxworks.rs
index beb20aa4816..7446471ae31 100644
--- a/src/libstd/sys/vxworks/process/process_vxworks.rs
+++ b/src/libstd/sys/vxworks/process/process_vxworks.rs
@@ -54,8 +54,8 @@ impl Command {
 
             let ret = libc::rtpSpawn(
                 self.get_argv()[0],                   // executing program
-                self.get_argv().as_ptr() as *const _, // argv
-                *sys::os::environ() as *const *const c_char,
+                self.get_argv().as_ptr() as *mut *const c_char, // argv
+                *sys::os::environ() as *mut *const c_char,
                 100 as c_int,                         // initial priority
                 thread::min_stack(),                  // initial stack size.
                 0,                                    // options